@@ -14,5 +14,5 @@ class TestDBUtils(unittest.TestCase):
         user_agent = svc_code
         queues = get_queue_properties(url, plat_key, svc_code, profile, user_agent)
         for (k, v) in queues.items():
-            print("mq-n:%s, ip:%s, port:%d, vhost:%s, username:%s, password:%s" %
-                  (k, v["ip"], v["port"], v["vhost"], v["username"], v["password"]))
+            print("mq-n:%s, ip:%s, port:%d, vhost:%s, username:%s, password:%s, cluster:%s, topic:%s" %
+                  (k, v["ip"], v["port"], v["vhost"], v["username"], v["password"], v["cluster"], v["topic"]))
